@@ -1,13 +1,12 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 from trytond.model import fields
 from trytond.pool import PoolMeta
 
 __all__ = ['Carrier']
-__metaclass__ = PoolMeta
 
 
-class Carrier:
+class Carrier(metaclass=PoolMeta):
     __name__ = 'carrier'
     carrier_cost_allocation_method = fields.Selection([
             ('value', 'By Value'),
